@@ -16,7 +16,7 @@ use 5.010001;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.876';
+our $VERSION = '1.877';
 
 ## no critic (Subroutines::ProhibitExplicitReturnUndef)
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
@@ -511,7 +511,7 @@ sub _prune_head {
    my %size = ( '' => 1, k => 1024, m => 1048576 );
 
    # Digital Information Sizes Calculator
-   # http://dr-lex.be/info-stuff/bytecalc.html
+   # https://dr-lex.be/info-stuff/bytecalc.html
 
    sub _size {
       my ( $size ) = @_;
@@ -778,7 +778,7 @@ sub purge {
 
 ###############################################################################
 ## ----------------------------------------------------------------------------
-## Sugar API, mostly resembles http://redis.io/commands#string primitives.
+## Sugar API, mostly resembles https://redis.io/commands#string primitives.
 ##
 ###############################################################################
 
@@ -902,7 +902,7 @@ MCE::Shared::Cache - A hybrid LRU-plain cache helper class
 
 =head1 VERSION
 
-This document describes MCE::Shared::Cache version 1.876
+This document describes MCE::Shared::Cache version 1.877
 
 =head1 DESCRIPTION
 
@@ -1553,7 +1553,7 @@ and C<get> explicitly. In shared context, the benefit is atomicity and
 reduction in inter-process communication.
 
 The API resembles a subset of the Redis primitives
-L<http://redis.io/commands#strings> with key representing the cache key.
+L<https://redis.io/commands#strings> with key representing the cache key.
 
 Optionally in v1.839 and later releases, give the number of seconds
 before the key is expired, similarly to C<set>.
