@@ -13,7 +13,7 @@ use 5.010001;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.876';
+our $VERSION = '1.877';
 
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
 
@@ -233,7 +233,7 @@ sub mset {
 
 ###############################################################################
 ## ----------------------------------------------------------------------------
-## Sugar API, mostly resembles http://redis.io/commands#string primitives.
+## Sugar API, mostly resembles https://redis.io/commands#string primitives.
 ##
 ###############################################################################
 
@@ -314,7 +314,7 @@ MCE::Shared::Hash - Hash helper class
 
 =head1 VERSION
 
-This document describes MCE::Shared::Hash version 1.876
+This document describes MCE::Shared::Hash version 1.877
 
 =head1 DESCRIPTION
 
@@ -771,7 +771,7 @@ and C<get> explicitly. In shared context, the benefit is atomicity and
 reduction in inter-process communication.
 
 The API resembles a subset of the Redis primitives
-L<http://redis.io/commands#strings> with key representing the hash key.
+L<https://redis.io/commands#strings> with key representing the hash key.
 
 =head2 append ( key, string )
 
