@@ -25,7 +25,7 @@ use 5.010001;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.876';
+our $VERSION = '1.877';
 
 ## no critic (Subroutines::ProhibitExplicitReturnUndef)
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
@@ -669,7 +669,7 @@ sub _reorder {
 
 ###############################################################################
 ## ----------------------------------------------------------------------------
-## Sugar API, mostly resembles http://redis.io/commands#string primitives.
+## Sugar API, mostly resembles https://redis.io/commands#string primitives.
 ##
 ###############################################################################
 
@@ -810,7 +810,7 @@ MCE::Shared::Ordhash - An ordered hash class featuring tombstone deletion
 
 =head1 VERSION
 
-This document describes MCE::Shared::Ordhash version 1.876
+This document describes MCE::Shared::Ordhash version 1.877
 
 =head1 DESCRIPTION
 
@@ -1379,7 +1379,7 @@ and C<get> explicitly. In shared context, the benefit is atomicity and
 reduction in inter-process communication.
 
 The API resembles a subset of the Redis primitives
-L<http://redis.io/commands#strings> with key representing the hash key.
+L<https://redis.io/commands#strings> with key representing the hash key.
 
 =head2 append ( key, string )
 
